pub enum BasinEndpoint {
ParentZone(Authority),
Direct(Authority),
}👎Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Endpoint for connecting to an S2 basin.
Variants
ParentZone(Authority)
👎Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Parent zone for basins. DNS is used to route to the correct cell for the basin.
Direct(Authority)
👎Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Direct cell endpoint.
The S2-Basin header is included in requests to specify the basin,
which is expected to be hosted by this cell.