pub enum TimestampingMode {
ClientPrefer,
ClientRequire,
Arrival,
}๐Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Timestamping mode. Note that arrival time is always in milliseconds since Unix epoch.
Variants
ClientPrefer
๐Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Prefer client-specified timestamp if present otherwise use arrival time.
ClientRequire
๐Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Require a client-specified timestamp and reject the append if it is missing.
Arrival
๐Deprecated since 0.21.1:
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Use the arrival time and ignore any client-specified timestamp.