pub struct AccessTokenInfo {
pub id: AccessTokenId,
pub expires_at: Option<u32>,
pub auto_prefix_streams: bool,
pub scope: Option<AccessTokenScope>,
}This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Access token information.
Fields
id: AccessTokenIdThis crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Access token ID. It must be unique to the account and between 1 and 96 characters.
expires_at: Option<u32>This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Expiration time in seconds since Unix epoch. If not set, the expiration will be set to that of the requestor’s token.
auto_prefix_streams: boolThis crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Namespace streams based on the configured stream-level scope, which must be a prefix. Stream name arguments will be automatically prefixed, and the prefix will be stripped when listing streams.
scope: Option<AccessTokenScope>This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Access token scope.
Implementations
Sourceimpl AccessTokenInfo
impl AccessTokenInfo
Sourcepub fn new(id: AccessTokenId) -> Self
👎Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn new(id: AccessTokenId) -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Create a new access token info.
Examples found in repository?
10async fn main() -> Result<(), Box<dyn std::error::Error>> {
11 let token = std::env::var("S2_ACCESS_TOKEN")?;
12 let config = ClientConfig::new(token);
13 let client = Client::new(config);
14
15 let access_token_id: AccessTokenId = "my-access-token".parse()?;
16 let access_token_info = AccessTokenInfo::new(access_token_id).with_scope(
17 AccessTokenScope::new()
18 .with_op_groups(
19 PermittedOperationGroups::new()
20 .with_account(ReadWritePermissions::new().with_read(true)),
21 )
22 .with_op(Operation::CreateStream)
23 .with_streams(ResourceSet::Prefix("my-stream-prefix".to_string()))
24 .with_basins(ResourceSet::Exact("my-perfect-basin".to_string())),
25 );
26 let token = client.issue_access_token(access_token_info).await?;
27
28 println!("Access token: {token}");
29
30 Ok(())
31}Sourcepub fn with_expires_at(self, expires_at: u32) -> Self
👎Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn with_expires_at(self, expires_at: u32) -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Overwrite expiration time.
Sourcepub fn with_auto_prefix_streams(self, auto_prefix_streams: bool) -> Self
👎Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn with_auto_prefix_streams(self, auto_prefix_streams: bool) -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Overwrite auto prefix streams.
Sourcepub fn with_scope(self, scope: AccessTokenScope) -> Self
👎Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn with_scope(self, scope: AccessTokenScope) -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Overwrite scope.
Examples found in repository?
10async fn main() -> Result<(), Box<dyn std::error::Error>> {
11 let token = std::env::var("S2_ACCESS_TOKEN")?;
12 let config = ClientConfig::new(token);
13 let client = Client::new(config);
14
15 let access_token_id: AccessTokenId = "my-access-token".parse()?;
16 let access_token_info = AccessTokenInfo::new(access_token_id).with_scope(
17 AccessTokenScope::new()
18 .with_op_groups(
19 PermittedOperationGroups::new()
20 .with_account(ReadWritePermissions::new().with_read(true)),
21 )
22 .with_op(Operation::CreateStream)
23 .with_streams(ResourceSet::Prefix("my-stream-prefix".to_string()))
24 .with_basins(ResourceSet::Exact("my-perfect-basin".to_string())),
25 );
26 let token = client.issue_access_token(access_token_info).await?;
27
28 println!("Access token: {token}");
29
30 Ok(())
31}Trait Implementations
Sourceimpl Clone for AccessTokenInfo
impl Clone for AccessTokenInfo
Sourcefn clone(&self) -> AccessTokenInfo
fn clone(&self) -> AccessTokenInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl Freeze for AccessTokenInfo
impl RefUnwindSafe for AccessTokenInfo
impl Send for AccessTokenInfo
impl Sync for AccessTokenInfo
impl Unpin for AccessTokenInfo
impl UnsafeUnpin for AccessTokenInfo
impl UnwindSafe for AccessTokenInfo