pub struct TimestampingConfig {
pub mode: Option<TimestampingMode>,
pub uncapped: Option<bool>,
}This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Timestamping behavior.
Fields
mode: Option<TimestampingMode>This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Timestamping mode for appends that influences how timestamps are handled.
uncapped: Option<bool>This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Allow client-specified timestamps to exceed the arrival time. If this is false or not set, client timestamps will be capped at the arrival time.
Implementations
Sourceimpl TimestampingConfig
impl TimestampingConfig
Sourcepub fn new() -> Self
๐Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn new() -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Create a new timestamping config.
Sourcepub fn with_mode(self, mode: TimestampingMode) -> Self
๐Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn with_mode(self, mode: TimestampingMode) -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Overwrite timestamping mode.
Sourcepub fn with_uncapped(self, uncapped: bool) -> Self
๐Deprecated since 0.21.1: This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
pub fn with_uncapped(self, uncapped: bool) -> Self
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Overwrite the uncapped knob.