pub enum ReadOutput {
Batch(SequencedRecordBatch),
NextSeqNum(u64),
}This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Batch of records or the next sequence number on the stream.
Variants
Batch(SequencedRecordBatch)
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Batch of records. It can only be empty when not in a session context, if the request cannot be satisfied without violating its limit.
NextSeqNum(u64)
This crate has been renamed to s2-sdk. Please update your Cargo.toml to use s2-sdk instead.
Tail of the stream, i.e. sequence number that will be assigned to the next record. It will be returned if the requested starting position is greater than the tail, or only in case of a limited read, equal to it. It will also be returned if there are no records on the stream between the requested starting position and the tail.